"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ReadiumView = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _interfaces = require("../interfaces");

var _utils = require("../utils");

var _BaseReadiumView = require("./BaseReadiumView");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const ReadiumView = _ref => {
  let {
    onLocationChange: wrappedOnLocationChange,
    onTableOfContents: wrappedOnTableOfContents,
    settings: unmappedSettings,
    ...props
  } = _ref;
  const ref = (0, _react.useRef)(null);
  const [{
    height,
    width
  }, setDimensions] = (0, _react.useState)({
    width: 0,
    height: 0
  }); // set the view dimensions on layout

  const onLayout = (0, _react.useCallback)(_ref2 => {
    let {
      nativeEvent: {
        layout: {
          width,
          height
        }
      }
    } = _ref2;
    setDimensions({
      width: (0, _utils.getWidthOrHeightValue)(width),
      height: (0, _utils.getWidthOrHeightValue)(height)
    });
  }, []); // wrap the native onLocationChange and extract the raw event value

  const onLocationChange = (0, _react.useCallback)(event => {
    if (wrappedOnLocationChange) {
      wrappedOnLocationChange(event.nativeEvent);
    }
  }, [wrappedOnLocationChange]);
  const onTableOfContents = (0, _react.useCallback)(event => {
    if (wrappedOnTableOfContents) {
      const toc = event.nativeEvent.toc || null;
      wrappedOnTableOfContents(toc);
    }
  }, [wrappedOnTableOfContents]);
  (0, _react.useEffect)(() => {
    if (_reactNative.Platform.OS === 'android') {
      const viewId = (0, _reactNative.findNodeHandle)(ref.current);
      (0, _utils.createFragment)(viewId);
    }
  }, []);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container,
    onLayout: onLayout
  }, /*#__PURE__*/_react.default.createElement(_BaseReadiumView.BaseReadiumView, _extends({
    height: height,
    width: width
  }, props, {
    onLocationChange: onLocationChange,
    onTableOfContents: onTableOfContents,
    settings: unmappedSettings ? _interfaces.Settings.map(unmappedSettings) : undefined,
    ref: ref
  })));
};

exports.ReadiumView = ReadiumView;

const styles = _reactNative.StyleSheet.create({
  container: {
    width: '100%',
    height: '100%'
  }
});
//# sourceMappingURL=ReadiumView.js.map