function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useCallback, useState, useRef, useEffect } from 'react';
import { View, Platform, findNodeHandle, StyleSheet } from 'react-native';
import { Settings } from '../interfaces';
import { createFragment, getWidthOrHeightValue as dimension } from '../utils';
import { BaseReadiumView } from './BaseReadiumView';
export const ReadiumView = _ref => {
  let {
    onLocationChange: wrappedOnLocationChange,
    onTableOfContents: wrappedOnTableOfContents,
    settings: unmappedSettings,
    ...props
  } = _ref;
  const ref = useRef(null);
  const [{
    height,
    width
  }, setDimensions] = useState({
    width: 0,
    height: 0
  }); // set the view dimensions on layout

  const onLayout = useCallback(_ref2 => {
    let {
      nativeEvent: {
        layout: {
          width,
          height
        }
      }
    } = _ref2;
    setDimensions({
      width: dimension(width),
      height: dimension(height)
    });
  }, []); // wrap the native onLocationChange and extract the raw event value

  const onLocationChange = useCallback(event => {
    if (wrappedOnLocationChange) {
      wrappedOnLocationChange(event.nativeEvent);
    }
  }, [wrappedOnLocationChange]);
  const onTableOfContents = useCallback(event => {
    if (wrappedOnTableOfContents) {
      const toc = event.nativeEvent.toc || null;
      wrappedOnTableOfContents(toc);
    }
  }, [wrappedOnTableOfContents]);
  useEffect(() => {
    if (Platform.OS === 'android') {
      const viewId = findNodeHandle(ref.current);
      createFragment(viewId);
    }
  }, []);
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container,
    onLayout: onLayout
  }, /*#__PURE__*/React.createElement(BaseReadiumView, _extends({
    height: height,
    width: width
  }, props, {
    onLocationChange: onLocationChange,
    onTableOfContents: onTableOfContents,
    settings: unmappedSettings ? Settings.map(unmappedSettings) : undefined,
    ref: ref
  })));
};
const styles = StyleSheet.create({
  container: {
    width: '100%',
    height: '100%'
  }
});
//# sourceMappingURL=ReadiumView.js.map